mysql.stmt.bind_out.Output_Stream

Package mysql :: Package stmt :: Module bind_out :: Class Output_Stream |
[hide private]
[frames] | no frames]

# Class Output_Stream

    object --+
             |
            Output_Stream

Output stream.

This is the object placed into your output binding that will relay data from MySQL.

Instance Methods | [hide private]
`` | __init__(...) x.__init__(...) initializes x; see x.__class__.__doc__ for signature
`` | __new__(T, S, ...) Returns a new object with type S, a subtype of T...
`` | read(...) Read data from the stream.
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables | [hide private]
`` | __pyx_vtable__ = `<PyCObject object at 0x852e908>`

Instance Variables | [hide private]
`` | _bind The MYSQL_BIND structure (initialized in __init__).
`` | _column The column number.
`` | _connection The mysql.connection.Connection object.
`` | _error Whether or not there was an error retrieving the value.
`` | _length The length of the value as reported by MySQL.
`` | _offset The current offset into the result.
`` | _raise_error A callable object used to raise a MySQL error.
`` | _statement The mysql.stmt.Statement object.
`` | _stmt MYSQL_STMT structure.

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(...) (Constructor) |
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__

### __new__(T, S, ...) |
    Returns:
        a new object with type S, a subtype of T
Overrides: object.__new__

### read(...) |
Read data from the stream. Note This will close any live unbuffered result objects and reset any live statement objects. Parameters: `bytes` - The number of bytes to read. If not specified, it will read all bytes that are left. Returns: Returns a string of data. Returns an empty string if there is no more data. Raises: `mysql.exceptions.MySQL_Error` - Generic MySQL error.

Class Variable Details | [hide private]

    ### __pyx_vtable__ Value:
        <PyCObject object at 0x852e908>

Instance Variable Details | [hide private]

### _bind The MYSQL_BIND structure (initialized in __init__).

### _column The column number.

### _connection The mysql.connection.Connection object.

### _error Whether or not there was an error retrieving the value. Used for detecting truncation.

### _length The length of the value as reported by MySQL.

### _offset The current offset into the result.

### _raise_error A callable object used to raise a MySQL error. Takes no arguments.

### _statement The mysql.stmt.Statement object.

### _stmt MYSQL_STMT structure.